#
# spec file for package openstack-ec2-api
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define component ec2-api
%define groupname %{component}
%define username %{component}

%define version_unconverted 9.0.0.dev1

Name:           openstack-%{component}
Version:        9.0.0~dev1
Release:        1.3
Summary:        OpenStack EC2 API
License:        Apache-2.0
Group:          System/Management
Url:            https://launchpad.net/ec2-api
Source:         http://tarballs.openstack.org/ec2-api/ec2-api-master.tar.gz
Source1:        %{name}-api.service
Source2:        %{name}-metadata.service
Source3:        %{name}-s3.service
Source6:        %{name}.logrotate
Source10:       %name.conf
Source50:       README.config
BuildRequires:  systemd
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
Source99:       rpmlintrc
BuildRequires:  crudini
BuildRequires:  fdupes
BuildRequires:  openstack-suse-macros
BuildRequires:  python-pbr
BuildRequires:  python-setuptools
# for oslo-config-generator
BuildRequires:  python-oslo.concurrency
BuildRequires:  python-oslo.config
BuildRequires:  python2-oslo.db
BuildRequires:  python-oslo.log
BuildRequires:  python2-oslo.messaging
BuildRequires:  python2-oslo.service
Requires:       logrotate
Requires:       python >= 2.7
Requires:       python-ec2api = %{version}
Requires(post): sysconfig
Requires(pre):  pwdutils
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires(pre):  %insserv_prereq %fillup_prereq

%description
AWS EC2 and VPC API support in standalone service for OpenStack.
At first uses nova's EC2 API for non-VPC functionality.

%package -n python-ec2api
Summary:        OpenStack EC2 API - Python module
Group:          Development/Languages/Python
Requires:       python-Babel
Requires:       python-Paste
Requires:       python-PasteDeploy
Requires:       python-Routes
Requires:       python-SQLAlchemy
Requires:       python-WebOb
Requires:       python-botocore
Requires:       python-cinderclient
Requires:       python-cryptography
Requires:       python-eventlet
Requires:       python-glanceclient
Requires:       python-greenlet
Requires:       python-httplib2
Requires:       python-keystoneauth1
Requires:       python-keystoneclient
Requires:       python-lxml
Requires:       python-neutronclient
Requires:       python-novaclient
Requires:       python-openstackclient
Requires:       python2-oslo.cache
Requires:       python-oslo.concurrency
Requires:       python-oslo.config
Requires:       python-oslo.context
Requires:       python2-oslo.db
Requires:       python-oslo.log
Requires:       python-oslo.serialization
Requires:       python2-oslo.service
Requires:       python-oslo.utils
Requires:       python-pbr
Requires:       python-six
Requires:       python-sqlalchemy-migrate

%description -n python-ec2api
This package contains the core Python module of OpenStack EC2 API.


%package test
Summary:        OpenStack EC2 API - Testsuite
Group:          System/Management
Requires:       python-fixtures
Requires:       python-mock
Requires:       python-nose
Requires:       python-oslotest
Requires:       python-python-subunit
Requires:       python-testrepository
Requires:       python-testtools

%description test
The OpenStack EC2 API testsuite. It is used to verify the functionality of
OpenStack EC2 API and its components.


%package api
Summary:        OpenStack EC2 API - API
# prereq for creating the right openstack-nova user/group
Group:          System/Management
PreReq:         %{name} = %{version}

%description api
This package contains the OpenStack EC2 API - API service.


%package metadata
Summary:        OpenStack EC2 API - metadata
# prereq for creating the right openstack-nova user/group
Group:          System/Management
PreReq:         %{name} = %{version}

%description metadata
This package contains the OpenStack EC2 API - metadata service.


%package s3
Summary:        OpenStack EC2 API - s3
# prereq for creating the right openstack-nova user/group
Group:          System/Management
PreReq:         %{name} = %{version}
# openstack-nova-objectstore was removed in Mitaka (v13) from Nova
Provides:       openstack-nova-objectstore = 12.5
Obsoletes:      openstack-nova-objectstore < 12.5

%description s3
This package contains the OpenStack EC2 API - s3 service.


%prep
%setup -q -n %{component}-%{version_unconverted}
%openstack_cleanup_prep

%build
python setup.py build
oslo-config-generator --config-file=etc/ec2api/ec2api-config-generator.conf

%install
python setup.py install --root %{buildroot} --prefix %{_prefix}

### directories
install -d -m 755 %{buildroot}%{_localstatedir}/lib/ec2-api
install -d -m 750 %{buildroot}%{_localstatedir}/log/ec2-api
install -d -m 700 %{buildroot}%{_rundir}/ec2-api
install -D -m 644 %{SOURCE10} %{buildroot}/%_tmpfilesdir/%name.conf

### configuration files
install -p -D -m 640 %{SOURCE50} %{buildroot}%{_sysconfdir}/ec2api/README.config
install -p -D -m 640 etc/ec2api/ec2api.conf.sample %{buildroot}%{_sysconfdir}/ec2api/ec2api.conf
install -p -D -m 640 etc/ec2api/api-paste.ini %{buildroot}%{_sysconfdir}/ec2api/

### extra config dirs
install -d -m 755 %{buildroot}%{_sysconfdir}/ec2api/ec2api.conf.d/

# logrotate/etc.
install -p -D -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

### systemd unit files
mkdir -p %{buildroot}%{_sbindir} %{buildroot}%{_unitdir}
install -p -D -m 444 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}-api.service
install -p -D -m 444 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}-metadata.service
install -p -D -m 444 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}-s3.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}-api
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}-metadata
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}-s3

### set default configuration
%define ec2api_conf %{buildroot}%{_sysconfdir}/ec2api/ec2api.conf.d/010-ec2api.conf
crudini --set %{ec2api_conf} DEFAULT log_dir /var/log/ec2-api
crudini --set %{ec2api_conf} DEFAULT state_path /var/lib/ec2-api

%pre
%openstack_pre_user_group_create %{username} %{groupname}

%post
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%pre api
%service_add_pre %{name}-api.service

%preun api
%service_del_postun %{name}-api.service

%post api
%service_add_post %{name}-api.service

%postun api
%restart_on_update %{name}-api.service
%service_del_postun %{name}-api.service

%pre metadata
%service_add_pre %{name}-metadata.service

%preun metadata
%service_del_postun %{name}-metadata.service

%post metadata
%service_add_post %{name}-metadata.service

%postun metadata
%restart_on_update %{name}-metadata.service
%service_del_postun %{name}-metadata.service

%pre s3
%service_add_pre %{name}-s3.service

%preun s3
%service_del_postun %{name}-s3.service

%post s3
%service_add_post %{name}-s3.service

%postun s3
%restart_on_update %{name}-s3.service
%service_del_postun %{name}-s3.service

%files
%defattr(-,root,root,-)
%doc README.rst
%license LICENSE 
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %{_sysconfdir}/ec2api
%dir %{_sysconfdir}/ec2api/ec2api.conf.d/
%{_sysconfdir}/ec2api/README.config
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/ec2api/api-paste.ini
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/ec2api/ec2api.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/ec2api/ec2api.conf.d/010-ec2api.conf
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/log/ec2-api
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/lib/ec2-api
%_tmpfilesdir/%name.conf
%{_bindir}/ec2-api-manage

##{_bindir}/nova-all
###{_mandir}/man1/nova-all.1%{?ext_man}

%files -n python-ec2api
%defattr(-,root,root,-)
%license LICENSE
%{python_sitelib}/ec2api/
%{python_sitelib}/ec2_api-*.egg-info
# Part of test subpackage
%exclude %{python_sitelib}/ec2api/tests/unit/

%files api
%defattr(-,root,root,-)
%license LICENSE
%{_unitdir}/%{name}-api.service
%{_sbindir}/rc%{name}-api
%{_bindir}/ec2-api
##{_mandir}/man1/nova-api-os-compute.1%{?ext_man}

%files metadata
%defattr(-,root,root,-)
%license LICENSE
%{_unitdir}/%{name}-metadata.service
%{_sbindir}/rc%{name}-metadata
%{_bindir}/ec2-api-metadata

%files s3
%defattr(-,root,root,-)
%license LICENSE
%{_unitdir}/%{name}-s3.service
%{_sbindir}/rc%{name}-s3
%{_bindir}/ec2-api-s3

%files test
%defattr(-,root,root,-)
%license LICENSE
%{python_sitelib}/ec2api/tests/unit/

%changelog
* Tue Mar  5 2019 cloud-devel@suse.de
- Update to version ec2-api-9.0.0.dev1:
  * up version to 9.0.0 due to release 8.0.0
  8.0.0
* Sat Jan  5 2019 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev20:
  * Replace tripleo-scenario002-multinode with scenario002-standalone
* Mon Dec 24 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev19:
  * Use template for lower-constraints
  * Ignore floating ips not attached to instances
* Wed Dec 12 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev16:
  * Change openstack-dev to openstack-discuss
* Fri Nov 30 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev15:
  * move tripleo job to experimental
  * Remove tripleo newton and ocata jobs
* Mon Nov 19 2018 sjamgade@suse.com
- change service depedancy from mysql.service to mariadb.service
* Tue Nov 13 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev13:
  * fix tox python3 overrides
  * Drop all qpid related explanations
* Fri Nov  9 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev10:
  * change calls from neutron cli to openstack cli
* Sat Sep  1 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev9:
  * Remove install-guide-jobs
* Thu Aug 30 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev8:
  * switch documentation job to new PTI
* Wed Aug 29 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev7:
  * import zuul job settings from project-config
* Sat Aug 25 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev6:
  * add python 3.6 unit test job
* Fri Aug 24 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev5:
  * switch documentation job to new PTI
  * import zuul job settings from project-config
* Mon Aug 20 2018 nicolas.bock@suse.com
- Fix linter complains about licenses
* Fri Aug 17 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev3:
  * Added EC2 API Import Image support (via RegisterImage EC2 API call)
* Fri Aug  3 2018 cloud-devel@suse.de
- Update to version ec2-api-8.0.0.dev1:
  * up version for next release
  7.0.0
* Sun Jul  1 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev228:
  * Fix usage of isotime
* Thu Jun 28 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev227:
  * Add py36 testenv
* Sat Jun 23 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev226:
  * Port rally plugins to use proper modules
* Tue May 22 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev225:
  * Replace deprecated "auth\_uri" by "www\_authenticate\_uri"
* Sat May 19 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev223:
  * fix error url
* Tue May  8 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev222:
  * uncap eventlet
* Fri Mar 30 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev221:
  * synchronize default vpc creation across threads
* Tue Mar 27 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev219:
  * Updated from global requirements
* Sat Mar 24 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev218:
  * add lower-constraints job
* Fri Mar 23 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev217:
  * Remove intree ec2-api tempest tests
* Sun Mar 18 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev216:
  * Updated from global requirements
* Fri Mar 16 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev215:
  * skip addresses tests due to novaclient changes
* Sun Mar 11 2018 cloud-devel@suse.de
- Update to version ec2-api-7.0.0.dev214:
  * Update links in README
* Tue Feb 27 2018 tbechtold@suse.com
- Update to version ec2-api-7.0.0.dev213:
  * up version for master branch due to queens release
  * Fix the incorrect reference links
  * Updated from global requirements
  * Updated from global requirements
  * update documentation
  * Switch ec2 neutron-full job to use ec2api tempest plugin
* Sun Feb  4 2018 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev206:
  * Switch ec2-api gate job to use ec2api tempest plugin
* Sat Feb  3 2018 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev204:
  * Updated from global requirements
* Fri Feb  2 2018 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev202:
  * Move zuulv3 jobs to project repo
* Tue Jan 23 2018 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev201:
  * add ssl\_ca\_cert option to check client cert
  * remove deprecated options
* Fri Jan 19 2018 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev197:
  * Updated from global requirements
* Tue Jan 16 2018 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev196:
  * fix DB migration for MySQL
* Sun Dec 24 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev195:
  * handle new volume's status "reserved"
  * Updated from global requirements
* Wed Dec  6 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev192:
  * Updated from global requirements
* Tue Nov 21 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev191:
  * zuul: create zuul.yaml and run tripleo scenario002
* Sat Nov 18 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev190:
  * Updated from global requirements
* Mon Nov 13 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev189:
  * Updated from global requirements
* Sat Nov  4 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev188:
  * Updated from global requirements
* Sat Oct 21 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev187:
  * remove unused configuration options
  * rework tox.ini
  * rally: rework plugin
  * update of Installation Guide
* Mon Oct 16 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev179:
  * Updated from global requirements
  * fix for awscli in create\_config
* Sat Oct  7 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev176:
  * Remove SCREEN\_LOGDIR from devstack
  * Move install guides from install-guide/ to doc/source/install Update documentation index page
  * Add configuration reference to doc/source/configuration
* Tue Sep 26 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev172:
  * Updated from global requirements
* Fri Sep 22 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev171:
  * Updated from global requirements
  * fix ec2-api-metadata memcached overlap with nova-api
* Mon Sep 18 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev168:
  * Correct import of keystoneauth1 session
* Fri Sep 15 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev166:
  * Add rm to whitelist\_externals in tox.ini
* Thu Sep 14 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev164:
  * Add test\_cert.pem to .gitignore
  * Updated from global requirements
* Tue Sep  5 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev162:
  * Fix add\_role section in install.sh script
* Sun Sep  3 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev160:
  * Updated from global requirements
* Sat Sep  2 2017 cloud-devel@suse.de
- Update to version ec2-api-6.0.0.dev159:
  * up version in master for next Q-cycle
  * Updated from global requirements
* Fri Aug 25 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev157:
  * Updated from global requirements
* Wed Aug 23 2017 tbechtold@suse.com
- Cleanup Requires and BuildRequires
* Sat Aug 19 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev156:
  * Updated from global requirements
* Tue Aug 15 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev155:
  * Fix test\_check\_simple\_image\_attributes to pass with AMI images
* Sat Aug 12 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev153:
  * Use botocore in API instead of boto
* Tue Aug  8 2017 snica@suse.com
- Remove remove-tempest-entry-point.patch
  Re-enable tempest test suite
* Tue Aug  8 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev151:
  * Updated from global requirements
* Sat Aug  5 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev150:
  * fix comparision of security group rules
* Mon Jul 24 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev148:
  * Updated from global requirements
* Wed Jul 19 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev147:
  * Updated from global requirements
* Fri Jul 14 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev146:
  * Updated from global requirements
* Sat Jul  8 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev145:
  * Remove code that used nova-cert
  * Add .idea pattern to .gitignore
* Fri Jul  7 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev141:
  * fix register\_image function
* Tue Jul  4 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev139:
  * Delete log translation functions and add hacking rule
  * Enable some off-by-default checks
  * Updated from global requirements
* Fri Jun 16 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev134:
  * turn on disable\_ec2\_classic in devstack installation
  * Updated from global requirements
* Fri Jun  9 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev131:
  * Updated from global requirements
  * Updated from global requirements
  * add using cache to metadata
* Tue Jun  6 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev126:
  * minor fix to https://review.openstack.org/#/c/466115/
  * Updated from global requirements
* Mon Jun  5 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev123:
  * Fix html\_last\_updated\_fmt for Python3
* Sun Jun  4 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev121:
  * Updated from global requirements
* Sat Jun  3 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev120:
  * Updated from global requirements
  * Updated from global requirements
* Thu Jun  1 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev118:
  * Updated from global requirements
* Sat May 27 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev117:
  * Updated from global requirements
* Fri May 26 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev116:
  * fix ec2-api after deprecation of nova-network functions in novaclient
  * Remove the deprecated tempest.test.attr
  * Updated from global requirements
  * Remove log translations
* Mon May 15 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev109:
  * Updated from global requirements
* Thu May  4 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev108:
  * Updated from global requirements
  * Updated from global requirements
* Wed May  3 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev106:
  * Using neutron engine in security groups describe
* Sat Apr 29 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev104:
  * fix keystone\_ec2\_tokens\_url
  * fix rally scenarios
* Wed Apr 26 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev102:
  * Add 'rm -f .testrepository/times.dbm' command in testenv
* Tue Apr 25 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev101:
  * fix documentation errors
  * change manual in install-guide
  * change the command to obtain credentials in README
  * Removing py34 from tox
  * Switch to use stable remote\_client
  * Switch to use stable data\_utils
  * turn on disable\_ec2\_classic
  * rework test for \_create\_vpc
  * fix tests for network\_interface
  * Don't pass argument sqlite\_db in method set\_defaults
  * fix security\_groups comparision due to neutron changes
  * fix security\_groups's rules comparision
  * fix experimental pipeline with post\_test\_hook.sh
  * Graduate to the oslo\_utils.fileutils
  * switch from deprecated tempest\_lib to tempest.lib
  * fix encoding of request\_id
  * Replace oslo\_utils.timeutils.isotime
  * fix installing virtualenv in post\_test\_hook
  * fix installing ec2api in devstack with USE\_SSL=True
  * functional tests: fix run\_ssh detection
  * functional tests: add 'run\_ssh' parameter to config
  * functional tests: remove unneeded describe\_addresses
  * functional test: fix instance\_stop\_start test
  * Add an explanation for ec2\_id metadata in images
  * Prevent updating os\_id of db items
  * py34: fix convert\_dicts\_to\_lists
  * py34: update tests/unit/\_\_init\_\_.py
  * remove content of tests/\_\_init\_\_.py
  * use request id generator from oslo\_context
  * Honour API\_WORKERS setting in devstack plugin
* Thu Apr 20 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev95:
  * Replace six.iteritems() with .items()
* Thu Apr 20 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev93:
  * use glanceclient version '2'. fix keystone error message
  * Updated from global requirements
  * Switch to use stable remote_client
* Fri Mar 10 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev88:
  * Switch to use stable data_utils
  * switch on vpnaas for ec2-api
  * Updated from global requirements
  * Updated from global requirements
  * turn on disable_ec2_classic
  * small fixes to default vpc implementation
* Tue Feb 28 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev80:
  * Changes in address in default VPC mode
  * add unit tests for create, delete security group and authorize security group ingress in case of default vpc
  * describe-security-groups by name in default VPC mode describes security groups in default vpc only
  * Changes in security groups in default VPC mode
  * add instance in default-vpc by security-group-name  or private-ip-address
* Tue Feb 21 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev70:
  * Use hacking 0.12.x
* Sun Feb 19 2017 cloud-devel@suse.de
- Update to version ec2-api-5.0.0.dev69:
  * increase version for master branch
* Tue Feb 14 2017 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev68:
  * Updated from global requirements
* Sat Feb 11 2017 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev67:
  * Updated from global requirements
  * Updated from global requirements
* Thu Feb  9 2017 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev65:
  * Create new instance by default in default vpc
  * Create default vpc during describe security groups
* Tue Feb  7 2017 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev61:
  * Typo-fix: occured => occurred
* Wed Jan 25 2017 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev60:
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * add account attributes to disabled ec2-classic mode
  * config option for default VPC
  * rework test for _create_vpc
  * add default route to route table of default vpc
* Sat Jan 14 2017 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev49:
  * reworked unit tests
  * Create internet gateway for default VPC
* Thu Jan 12 2017 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev45:
  * Create default VPC during describe route tables
  * add unit test for check and create default vpc function
* Tue Jan 10 2017 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev41:
  * Create a subnet for default VPC
* Thu Jan  5 2017 dmueller@suse.com
- call db_sync to create the database
* Tue Jan  3 2017 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev39:
  * Updated from global requirements
* Fri Dec 30 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev38:
  * create default vpc
  * Switch to Nova v2.32 API
  * Honor Nova's restriction for bdm fields
* Sat Dec 24 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev34:
  * Updated from global requirements
* Fri Dec 23 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev33:
  * Add Constraints support
* Wed Dec 21 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev32:
  * add CONTRIBUTING.rst
* Mon Dec 19 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev31:
  * H803 hacking have been deprecated
* Fri Dec 16 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev30:
  * add API reference documentation
  * fix format errors in README file remove Legacy OpenStack release notice
  * Updated from global requirements
* Thu Dec 15 2016 tbechtold@suse.com
- config cleanup
* Wed Dec 14 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev26:
  * modified README.rst
* Tue Dec 13 2016 aplanas@suse.com
- Create /etc/ec2api/ec2api.conf.d
* Sat Dec 10 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev25:
  * added install-guide documentation
  * Updated from global requirements
  * use 'strongswan' package for vpnaas
* Wed Dec  7 2016 aplanas@suse.com
- systemd: remove Wants from services.
* Fri Dec  2 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev20:
  * try to fix stages problem of devstack
* Tue Nov 29 2016 steven.kowalik@suse.com
- Add missing %%pre blocks for transition to systemd service files.
* Tue Nov 29 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev19:
  * Remove unnecessary file
* Mon Nov 28 2016 steven.kowalik@suse.com
- Switch to systemd service files.
- Transition to /var/run/ec2-api
* Mon Nov 28 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev17:
  * Show team and repo badges on README
  * fix tests for network_interface
* Tue Nov 15 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev15:
  * Updated from global requirements
* Wed Nov  9 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev14:
  * Add tempest test UUID to all functional tests
* Tue Nov  8 2016 slunkad@suse.com
- Corrects name of api deamon
* Tue Nov  8 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev12:
  * Updated from global requirements
* Thu Nov  3 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev11:
  * Don't pass argument sqlite_db in method set_defaults
* Wed Nov  2 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev9:
  * Don't attempt to escalate ec2-api-manage privileges
  * Drop MANIFEST.in - it's not needed by pbr
  * Updated from global requirements
* Fri Oct 14 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev3:
  * Updated from global requirements
* Thu Oct 13 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev2:
  * skip vpn tests if vpnaas is not in network features list
* Wed Oct 12 2016 cloud-devel@suse.de
- Update to version ec2-api-4.0.0.dev1:
  * up version in master
  3.0.0
* Tue Oct  4 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev448:
  * Updated from global requirements
  * Using assertIsNone() instead of assertEqual(None, ...)
  * Use assertEqual() instead of assertDictEqual()
* Fri Sep 30 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev443:
  * Trivial: Remove vim header from source files
* Thu Sep 22 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev442:
  * Updated from global requirements
* Wed Sep 21 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev441:
  * fix experimental jobs
  * rework creating admin context - use keystoneauth1 lib
  * Updated from global requirements
  * Fix tempest.conf generation
  * switch to using new versions of cinder service
  * add link to download devstack in README.rst
* Wed Sep 14 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev432:
  * fix security_groups comparision due to neutron changes
* Fri Sep  2 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev431:
  * fix metadata accessing for specific networks
  * Updated from global requirements
* Fri Aug 26 2016 aplanas@suse.com
- Revert generate PID file for systemd (bsc#991985)
* Thu Aug 25 2016 tbechtold@suse.com
- Fix test package
* Thu Aug 25 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev429:
  * Updated from global requirements
* Wed Aug 24 2016 aplanas@suse.com
- Generate PID file for systemd (bsc#991985)
* Wed Aug 24 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev428:
  * Fix group name when generating tempest.conf
  * Updated from global requirements
* Thu Aug 18 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev425:
  * fix rally plugin due to rally changes
* Tue Aug 16 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev424:
  * Updated from global requirements
  * use another params for upload-bundle
* Thu Aug 11 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev422:
  * restore configuring bundled image in s3
  * change default region
  * update from global requirements
  * functional tests: add skip checker for absence of EC2-classic
  * fix security_groups's rules comparision
* Sun Jul 31 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev417:
  * skip failed addresses test for nova-network
  * Removed mentioning of old EC2 API
* Fri Apr 22 2016 cloud-devel@suse.de
- Update to version ec2-api-3.0.0.dev414:
  * update from global requirements and up version for master
* Wed Apr 13 2016 cloud-devel@suse.de
- Rebased patches:
  + inherit-from-correct-class-for-wsgi-server.patch dropped (merged upstream)
* Wed Apr 13 2016 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev413:
  * Fix doc build if git is absent
  * fix experimental pipeline with post_test_hook.sh
  * Inherit from correct class for WSGI server
* Tue Apr  5 2016 johannes.grassler@suse.com
- Add patch file missing from previous change.
* Tue Apr  5 2016 johannes.grassler@suse.com
-  Add inherit-from-correct-class-for-wsgi-server.patch
  * Fixes startup crash caused by switch to oslo.service
* Mon Mar 28 2016 tbechtold@suse.com
- Set state_path and in ec2-api.conf and install /var/lib/ec2-api
* Sun Mar 27 2016 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev408:
  * Graduate from Oslo Incubator to using oslo.service
* Sat Mar 26 2016 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev406:
  * Graduate to the oslo_utils.fileutils
* Wed Mar 23 2016 tbechtold@suse.com
- Add remove-tempest-entry-point.patch
  There is currently no way in tempest to disable tests from plugins.
* Wed Mar 23 2016 tbechtold@suse.com
- PreReq openstack-ec2-api for creating username and group
- Require Python >= 2.7
* Sat Mar 19 2016 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev404:
  * Graduate to oslo.utils.timeutils
  * remove using euca2ools in install script
  * fix security group rules comparision
* Wed Mar 16 2016 tbechtold@suse.com
- Add Provides/Obsoletes for openstack-nova-objectstore
* Thu Mar  3 2016 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev400:
  * Install tempest into venv for non-tox way of functional tests
  * switch from deprecated tempest_lib to tempest.lib
* Fri Feb 26 2016 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev398:
  * use EBS image instead non-EBS image
  * add 'stop instance' operation before volume detach
  * update devstack plugin script
  * fix cleanup in functional tests
  * Improve functional tests
  * Set https connection verify flag from config
  * Change CIDR's in tests
  * Fix botoclient for non-ssl based functional tests
  * fix encoding of request_id
  * LOG.warn is deprecated in python3
  * rework accessing keystone resources
  * URL error for sqlalchemy-migrate doc
  * Remove argparse from requirements
  * Replace deprecated library function os.popen() with subprocess
  * rework rally
* Sun Dec 27 2015 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev383:
  * py33 are no longer supported by Infra's CI
* Sat Dec 26 2015 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev381:
  * fix of installation script and README file
  * fix functional tests
  * Fix 'unstack' script
  * fix VPC and VPN tests due to Amazon changes
* Sat Dec 19 2015 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev376:
  * Deprecated tox -downloadcache option removed
* Fri Dec 18 2015 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev375:
  * Update run method of devstack services
  * Replace oslo_utils.timeutils.isotime
* Thu Dec 17 2015 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev372:
  * fix rally
  * fix working with cinder API v2
  * fix races
* Wed Dec  9 2015 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev369:
  * fix metadata test
* Fri Nov 27 2015 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev368:
  * fix installing virtualenv in post_test_hook
* Fri Nov 20 2015 cloud-devel@suse.de
- Update to version ec2-api-2.0.0.dev367:
  * Update from global requirements and bump master version
* Thu Nov 19 2015 cloud-devel@suse.de
- Update to version ec2-api-1.0.0.dev366:
  * move config creation to devstack plugin script
  * Adopt functional tests to be a tempest plugin
* Tue Nov 17 2015 tbechtold@suse.com
- Initial packaging (version 1.0.0.dev364)
